#  Licensed to Elasticsearch B.V. under one or more contributor
#  license agreements. See the NOTICE file distributed with
#  this work for additional information regarding copyright
#  ownership. Elasticsearch B.V. licenses this file to you under
#  the Apache License, Version 2.0 (the "License"); you may
#  not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
# 	http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing,
#  software distributed under the License is distributed on an
#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
#  KIND, either express or implied.  See the License for the
#  specific language governing permissions and limitations
#  under the License.

import sys
from typing import Tuple

from .client import Elasticsearch as Elasticsearch
from .transport import Transport as Transport
from .connection_pool import (
    ConnectionPool as ConnectionPool,
    ConnectionSelector as ConnectionSelector,
    RoundRobinSelector as RoundRobinSelector,
)
from .serializer import JSONSerializer as JSONSerializer
from .connection import (
    Connection as Connection,
    RequestsHttpConnection as RequestsHttpConnection,
    Urllib3HttpConnection as Urllib3HttpConnection,
)
from .exceptions import (
    ImproperlyConfigured as ImproperlyConfigured,
    ElasticsearchException as ElasticsearchException,
    SerializationError as SerializationError,
    TransportError as TransportError,
    NotFoundError as NotFoundError,
    ConflictError as ConflictError,
    RequestError as RequestError,
    ConnectionError as ConnectionError,
    SSLError as SSLError,
    ConnectionTimeout as ConnectionTimeout,
    AuthenticationException as AuthenticationException,
    AuthorizationException as AuthorizationException,
    ElasticsearchDeprecationWarning as ElasticsearchDeprecationWarning,
)

try:
    if sys.version_info < (3, 6):
        raise ImportError

    from ._async.http_aiohttp import AIOHttpConnection as AIOHttpConnection
    from ._async.transport import AsyncTransport as AsyncTransport
    from ._async.client import AsyncElasticsearch as AsyncElasticsearch
except (ImportError, SyntaxError):
    pass

VERSION: Tuple[int, int, int]
__version__: Tuple[int, int, int]
__versionstr__: str



#  Licensed to Elasticsearch B.V. under one or more contributor
#  license agreements. See the NOTICE file distributed with
#  this work for additional information regarding copyright
#  ownership. Elasticsearch B.V. licenses this file to you under
#  the Apache License, Version 2.0 (the "License"); you may
#  not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
# 	http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing,
#  software distributed under the License is distributed on an
#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
#  KIND, either express or implied.  See the License for the
#  specific language governing permissions and limitations
#  under the License.

from typing import Optional, Any, Mapping
import requests
from .base import Connection

class RequestsHttpConnection(Connection):
    session: requests.Session
    def __init__(
        self,
        host: str = ...,
        port: Optional[int] = ...,
        http_auth: Optional[Any] = ...,
        use_ssl: bool = ...,
        verify_certs: bool = ...,
        ssl_show_warn: bool = ...,
        ca_certs: Optional[Any] = ...,
        client_cert: Optional[Any] = ...,
        client_key: Optional[Any] = ...,
        headers: Optional[Mapping[str, str]] = ...,
        http_compress: Optional[bool] = ...,
        cloud_id: Optional[str] = ...,
        api_key: Optional[Any] = ...,
        opaque_id: Optional[str] = ...,
        **kwargs: Any
    ) -> None: ...



#  Licensed to Elasticsearch B.V. under one or more contributor
#  license agreements. See the NOTICE file distributed with
#  this work for additional information regarding copyright
#  ownership. Elasticsearch B.V. licenses this file to you under
#  the Apache License, Version 2.0 (the "License"); you may
#  not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
# 	http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing,
#  software distributed under the License is distributed on an
#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
#  KIND, either express or implied.  See the License for the
#  specific language governing permissions and limitations
#  under the License.

import sys
from .errors import BulkIndexError as BulkIndexError, ScanError as ScanError
from .actions import (
    expand_action as expand_action,
    streaming_bulk as streaming_bulk,
    bulk as bulk,
    parallel_bulk as parallel_bulk,
    scan as scan,
    reindex as reindex,
    _chunk_actions as _chunk_actions,
    _process_bulk_chunk as _process_bulk_chunk,
)

try:
    # Asyncio only supported on Python 3.6+
    if sys.version_info < (3, 6):
        raise ImportError

    from .._async.helpers import (
        async_scan as async_scan,
        async_bulk as async_bulk,
        async_reindex as async_reindex,
        async_streaming_bulk as async_streaming_bulk,
    )
except (ImportError, SyntaxError):
    pass
